==> sparkpipelineframework-2.0.50.tar.gz: sparkpipelineframework-2.0.50/spark_pipeline_framework/utilities/fhir_helpers/get_fhir_client.py <==
from logging import Logger
from typing import Optional, List

from helix_fhir_client_sdk.fhir_client import FhirClient

from spark_pipeline_framework.utilities.fhir_helpers.token_helper import TokenHelper


def get_fhir_client(
    logger: Logger,
    server_url: str,
    auth_server_url: Optional[str] = None,
    auth_client_id: Optional[str] = None,
    auth_client_secret: Optional[str] = None,
    auth_login_token: Optional[str] = None,
    auth_access_token: Optional[str] = None,
    auth_scopes: Optional[List[str]] = None,
    log_level: Optional[str] = None,
    auth_well_known_url: Optional[str] = None,
) -> FhirClient:
    assert server_url

    fhir_client: FhirClient = FhirClient()
    fhir_client = fhir_client.url(server_url)

    if log_level:
        fhir_client = fhir_client.log_level(log_level)

    if auth_server_url:
        fhir_client = fhir_client.auth_server_url(auth_server_url)
    if auth_well_known_url:
        auth_server_url_from_wellknown: Optional[str] = (
            TokenHelper.get_auth_server_url_from_well_known_url(
                well_known_url=auth_well_known_url
            )
        )
        if auth_server_url_from_wellknown:
            fhir_client = fhir_client.auth_server_url(auth_server_url_from_wellknown)
    if auth_client_id and auth_client_secret:
        fhir_client = fhir_client.client_credentials(auth_client_id, auth_client_secret)
    if auth_login_token:
        fhir_client = fhir_client.login_token(auth_login_token)
    if auth_access_token:
        fhir_client = fhir_client.set_access_token(auth_access_token)
    if auth_scopes:
        fhir_client = fhir_client.auth_scopes(auth_scopes)

    if logger:
        # noinspection PyTypeChecker
        fhir_client = fhir_client.logger(logger)  # type: ignore

    return fhir_client

==> sparkpipelineframework-4.0.21a0.tar.gz: sparkpipelineframework-4.0.21a0/spark_pipeline_framework/utilities/fhir_helpers/get_fhir_client.py <==
import os
from logging import Logger
from typing import Optional, List

from helix_fhir_client_sdk.fhir_client import FhirClient


def get_fhir_client(
    logger: Logger,
    server_url: str,
    auth_server_url: Optional[str] = None,
    auth_client_id: Optional[str] = None,
    auth_client_secret: Optional[str] = None,
    auth_login_token: Optional[str] = None,
    auth_access_token: Optional[str] = None,
    auth_scopes: Optional[List[str]] = None,
    log_level: Optional[str] = None,
    auth_well_known_url: Optional[str] = None,
) -> FhirClient:
    assert server_url

    fhir_client: FhirClient = FhirClient()
    fhir_client = fhir_client.url(server_url)

    if log_level:
        fhir_client = fhir_client.log_level(log_level)

    auth_server_url = auth_server_url or os.environ.get("FHIR_AUTH_SERVER_URL")
    if auth_server_url:
        fhir_client = fhir_client.auth_server_url(auth_server_url)
    if auth_well_known_url:
        fhir_client = fhir_client.auth_wellknown_url(auth_well_known_url)
    if auth_client_id and auth_client_secret:
        fhir_client = fhir_client.client_credentials(auth_client_id, auth_client_secret)
    if auth_login_token:
        fhir_client = fhir_client.login_token(auth_login_token)
    if auth_access_token:
        fhir_client = fhir_client.set_access_token(auth_access_token)
    if auth_scopes:
        fhir_client = fhir_client.auth_scopes(auth_scopes)

    if logger:
        fhir_client = fhir_client.logger(logger)

    return fhir_client
